@@ -282,7 +282,7 @@ class Client(object):
         :type limit: number
 
         :param startingBefore: optional, defaults to now
-        :type startingBefore: str (ISO-8601)
+        :type startingBefore: str date and time (ISO-8601)
 
         :returns: list of existing orders
 
@@ -340,7 +340,7 @@ class Client(object):
         :type limit: number
 
         :param startingBefore: optional, defaults to now
-        :type startingBefore: str (ISO-8601)
+        :type startingBefore: str date and time (ISO-8601)
 
         :returns: list of existing orders
 
@@ -390,7 +390,7 @@ class Client(object):
         :type limit: number
 
         :param startingBefore: optional, defaults to now
-        :type startingBefore: str (ISO-8601)
+        :type startingBefore: str date and time (ISO-8601)
 
         :returns: list of processed fills
 
@@ -438,7 +438,7 @@ class Client(object):
         :type limit: number
 
         :param startingBefore: optional, defaults to now
-        :type startingBefore: str (ISO-8601)
+        :type startingBefore: str date and time (ISO-8601)
 
         :returns: list of existing fills
 
@@ -487,7 +487,7 @@ class Client(object):
         :type limit: number
 
         :param startingBefore: optional, defaults to now
-        :type startingBefore: str (ISO-8601)
+        :type startingBefore: str date and time (ISO-8601)
 
         :returns: list of existing trades
 
@@ -519,7 +519,7 @@ class Client(object):
         :type limit: number
 
         :param startingBefore: optional, defaults to now
-        :type startingBefore: str (ISO-8601)
+        :type startingBefore: str date and time (ISO-8601)
 
         :returns: list of processed trades
 
@@ -576,13 +576,13 @@ class Client(object):
         :type postOnly: bool
 
         :param clientId: optional, defaults to None
-        :type clientId: string
+        :type clientId: str
 
         :param cancelAmountOnRevert: optional, defaults to None
         :type cancelAmountOnRevert: bool
 
         :param cancelId: optional, defaults to None
-        :type cancelId: string
+        :type cancelId: str
 
         :returns: Order
 
@@ -664,7 +664,7 @@ class Client(object):
         hash
     ):
         '''
-        Cancel an order
+        Cancel an order in a solo market.
 
         :param hash: required
         :type hash: str
@@ -679,6 +679,26 @@ class Client(object):
             headers={'Authorization': 'Bearer ' + signature}
         )
 
+    def cancel_perpetual_order(
+        self,
+        hash
+    ):
+        '''
+        Cancel an order in a perpetual market.
+
+        :param hash: required
+        :type hash: str
+
+        :returns: Order
+
+        :raises: DydxAPIError
+        '''
+        signature = perp_orders.sign_cancel_order(hash, self.private_key)
+        return self._delete(
+            '/v2/orders/' + hash,
+            headers={'Authorization': 'Bearer ' + signature}
+        )
+
     def get_orderbook(
         self,
         market
@@ -717,7 +737,7 @@ class Client(object):
         '''
         Get all markets
 
-        :returns: { markets : { [market: string]: MarketMessageV2 } }
+        :returns: { markets : { [market: str]: MarketMessageV2 } }
 
         :raises: DydxAPIError
         '''
@@ -731,7 +751,7 @@ class Client(object):
         Get market from market pair
 
         :param market: required
-        :type market: str in list ["PBTC-DAI"]
+        :type market: str in list ["PBTC-USDC"]
 
         :returns: { market: PerpetualMarket }
 
@@ -745,8 +765,87 @@ class Client(object):
         '''
         Get all markets
 
-        :returns: { markets : [market: PerpetualMarket] }
+        :returns: { markets : [market: str]: PerpetualMarket } }
 
         :raises: DydxAPIError
         '''
         return self._get('/v1/perpetual-markets')
+
+    def get_funding_rates(
+        self,
+        markets=None,
+    ):
+        '''
+        Get the current and predicted funding rates.
+
+        IMPORTANT: The `current` value returned by this function is not active
+        until it has been mined on-chain, which may not happen for some period
+        of time after the start of the hour. To get the funding rate that is
+        currently active on-chain, use the get_perpetual_market() or
+        get_perpetual_markets() function.
+
+        The `current` rate is updated each hour, on the hour. The `predicted`
+        rate is updated each minute, on the minute, and may be null if no
+        premiums have been calculated since the last funding rate update.
+
+        :param markets: optional, defaults to all Perpetual markets
+        :type markets: str in list ["PBTC-USDC"]
+
+        :returns: {
+            [market: str]: { current: FundingRate, predicted: FundingRate }
+        }
+
+        :raises: DydxAPIError
+        '''
+        return self._get('/v1/funding-rates', params=utils.remove_nones({
+            'markets': None if markets is None else ','.join(markets),
+        }))
+
+    def get_historical_funding_rates(
+        self,
+        markets=None,
+        limit=None,
+        startingBefore=None,
+    ):
+        '''
+        Get historical funding rates.
+
+        :param markets: optional, defaults to all Perpetual markets
+        :type markets: str in list ["PBTC-USDC"]
+
+        :param limit: optional, defaults to 100, which is the maximum
+        :type limit: number
+
+        :param startingBefore: optional, defaults to now
+        :type startingBefore: str date and time (ISO-8601)
+
+        :returns: { [market: str]: { history: FundingRate[] } }
+
+        :raises: DydxAPIError
+        '''
+        return self._get(
+            '/v1/historical-funding-rates',
+            params=utils.remove_nones({
+                'markets': None if markets is None else ','.join(markets),
+                'limit': limit,
+                'startingBefore': startingBefore,
+            }),
+        )
+
+    def get_funding_index_price(
+        self,
+        markets=None,
+    ):
+        '''
+        Get the index price used in the funding rate calculation.
+
+        :param markets: optional, defaults to all Perpetual markets
+        :type markets: str in list ["PBTC-USDC"]
+
+        :returns: { [market: str]: { price: str } }
+
+        :raises: DydxAPIError
+        '''
+        return self._get('/v1/index-price', params=utils.remove_nones({
+            'markets': None if markets is None else ','.join(markets),
+        }))
